NuRadioReco.framework package
=============================

Submodules
----------

NuRadioReco.framework.base\_shower module
-----------------------------------------

.. automodule:: NuRadioReco.framework.base_shower
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.base\_station module
------------------------------------------

.. automodule:: NuRadioReco.framework.base_station
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.base\_trace module
----------------------------------------

.. automodule:: NuRadioReco.framework.base_trace
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.channel module
------------------------------------

.. automodule:: NuRadioReco.framework.channel
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.electric\_field module
--------------------------------------------

.. automodule:: NuRadioReco.framework.electric_field
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.event module
----------------------------------

.. automodule:: NuRadioReco.framework.event
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.hybrid\_information module
------------------------------------------------

.. automodule:: NuRadioReco.framework.hybrid_information
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.hybrid\_shower module
-------------------------------------------

.. automodule:: NuRadioReco.framework.hybrid_shower
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.parameter\_serialization module
-----------------------------------------------------

.. automodule:: NuRadioReco.framework.parameter_serialization
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.parameters module
---------------------------------------

.. automodule:: NuRadioReco.framework.parameters
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.radio\_shower module
------------------------------------------

.. automodule:: NuRadioReco.framework.radio_shower
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.sim\_station module
-----------------------------------------

.. automodule:: NuRadioReco.framework.sim_station
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.station module
------------------------------------

.. automodule:: NuRadioReco.framework.station
    :members:
    :undoc-members:
    :show-inheritance:

NuRadioReco.framework.trigger module
------------------------------------

.. automodule:: NuRadioReco.framework.trigger
    :members:
    :undoc-members:
    :show-inheritance:


Module contents
---------------

.. automodule:: NuRadioReco.framework
    :members:
    :undoc-members:
    :show-inheritance:
